@@ -6,4 +6,6 @@ May  15 12:04:49 2019
 from .__version__ import __version__
 from .launchpy import *
 from .configs import *
-from .library import *
\ No newline at end of file
+from .library import *
+from .admin import *
+from .property import *
\ No newline at end of file
